# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/access_analyzer_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/access_analyzer_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.iam.v1 import resource_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_resource__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/iam/v1/access_analyzer_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a\"yandex/cloud/iam/v1/resource.proto\x1a\x1dyandex/cloud/validation.proto\"\xab\x01\n ListSubjectAccessBindingsRequest\x12!\n\nsubject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12%\n\x0forganization_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\x88\x01\n!ListSubjectAccessBindingsResponse\x12J\n\x17subject_access_bindings\x18\x01 \x03(\x0b\x32).yandex.cloud.iam.v1.SubjectAccessBinding\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"l\n\x14SubjectAccessBinding\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12/\n\x08resource\x18\x02 \x01(\x0b\x32\x1d.yandex.cloud.iam.v1.Resource\x12\x12\n\nsubject_id\x18\x03 \x01(\t2\xcf\x01\n\x15\x41\x63\x63\x65ssAnalyzerService\x12\xb5\x01\n\x19ListSubjectAccessBindings\x12\x35.yandex.cloud.iam.v1.ListSubjectAccessBindingsRequest\x1a\x36.yandex.cloud.iam.v1.ListSubjectAccessBindingsResponse\")\x82\xd3\xe4\x93\x02#\x12!/iam/v1/listSubjectAccessBindingsBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.access_analyzer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['subject_id']._loaded_options = None
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_ACCESSANALYZERSERVICE'].methods_by_name['ListSubjectAccessBindings']._loaded_options = None
  _globals['_ACCESSANALYZERSERVICE'].methods_by_name['ListSubjectAccessBindings']._serialized_options = b'\202\323\344\223\002#\022!/iam/v1/listSubjectAccessBindings'
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST']._serialized_start=172
  _globals['_LISTSUBJECTACCESSBINDINGSREQUEST']._serialized_end=343
  _globals['_LISTSUBJECTACCESSBINDINGSRESPONSE']._serialized_start=346
  _globals['_LISTSUBJECTACCESSBINDINGSRESPONSE']._serialized_end=482
  _globals['_SUBJECTACCESSBINDING']._serialized_start=484
  _globals['_SUBJECTACCESSBINDING']._serialized_end=592
  _globals['_ACCESSANALYZERSERVICE']._serialized_start=595
  _globals['_ACCESSANALYZERSERVICE']._serialized_end=802
# @@protoc_insertion_point(module_scope)
