"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.assistant_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListAssistantsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """Project id"""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___ListAssistantsRequest = ListAssistantsRequest

@typing.final
class ListAssistantsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSISTANTS_FIELD_NUMBER: builtins.int
    @property
    def assistants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.assistant_pb2.Assistant]:
        """Assistants belonging to the given project"""

    def __init__(
        self,
        *,
        assistants: collections.abc.Iterable[yandex.cloud.speechsense.v1.assistant_pb2.Assistant] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assistants", b"assistants"]) -> None: ...

global___ListAssistantsResponse = ListAssistantsResponse

@typing.final
class ListModelsRequest(google.protobuf.message.Message):
    """No parameters"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListModelsRequest = ListModelsRequest

@typing.final
class ListModelsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODELS_FIELD_NUMBER: builtins.int
    @property
    def models(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.assistant_pb2.Model]: ...
    def __init__(
        self,
        *,
        models: collections.abc.Iterable[yandex.cloud.speechsense.v1.assistant_pb2.Model] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["models", b"models"]) -> None: ...

global___ListModelsResponse = ListModelsResponse
