# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/userpool.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/userpool.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/organizationmanager/v1/idp/userpool.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xd2\x06\n\x08Userpool\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12M\n\x06labels\x18\x05 \x03(\x0b\x32=.yandex.cloud.organizationmanager.v1.idp.Userpool.LabelsEntry\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x64omains\x18\x08 \x03(\t\x12H\n\x06status\x18\t \x01(\x0e\x32\x38.yandex.cloud.organizationmanager.v1.idp.Userpool.Status\x12L\n\ruser_settings\x18\n \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.UserSettings\x12_\n\x17password_quality_policy\x18\x0b \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.PasswordQualityPolicy\x12\x61\n\x18password_lifetime_policy\x18\x0c \x01(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.PasswordLifetimePolicy\x12i\n\x1c\x62ruteforce_protection_policy\x18\r \x01(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.idp.BruteforceProtectionPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\"\x8f\x01\n\x0cUserSettings\x12 \n\x18\x61llow_edit_self_password\x18\x01 \x01(\x08\x12\x1c\n\x14\x61llow_edit_self_info\x18\x02 \x01(\x08\x12 \n\x18\x61llow_edit_self_contacts\x18\x03 \x01(\x08\x12\x1d\n\x15\x61llow_edit_self_login\x18\x04 \x01(\x08\"\xb6\x03\n\x06\x44omain\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x46\n\x06status\x18\x02 \x01(\x0e\x32\x36.yandex.cloud.organizationmanager.v1.idp.Domain.Status\x12\x13\n\x0bstatus_code\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0cvalidated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12L\n\nchallenges\x18\x07 \x03(\x0b\x32\x38.yandex.cloud.organizationmanager.v1.idp.DomainChallenge\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\"l\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10NEED_TO_VALIDATE\x10\x01\x12\x0e\n\nVALIDATING\x10\x02\x12\t\n\x05VALID\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05J\x04\x08\x06\x10\x07\"\xaa\x05\n\x0f\x44omainChallenge\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12K\n\x04type\x18\x04 \x01(\x0e\x32=.yandex.cloud.organizationmanager.v1.idp.DomainChallenge.Type\x12O\n\x06status\x18\x05 \x01(\x0e\x32?.yandex.cloud.organizationmanager.v1.idp.DomainChallenge.Status\x12[\n\rdns_challenge\x18\x06 \x01(\x0b\x32\x42.yandex.cloud.organizationmanager.v1.idp.DomainChallenge.DnsRecordH\x00\x1a\xa6\x01\n\tDnsRecord\x12\x0c\n\x04name\x18\x01 \x01(\t\x12U\n\x04type\x18\x02 \x01(\x0e\x32G.yandex.cloud.organizationmanager.v1.idp.DomainChallenge.DnsRecord.Type\x12\r\n\x05value\x18\x03 \x01(\t\"%\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03TXT\x10\x01\")\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x44NS_TXT\x10\x01\"U\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\t\n\x05VALID\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x42\x0b\n\tchallengeJ\x04\x08\x03\x10\x04\"\xa5\x04\n\x15PasswordQualityPolicy\x12\x15\n\rallow_similar\x18\x01 \x01(\x08\x12\x1b\n\nmax_length\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x1b\n\nmin_length\x18\x03 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x1d\n\x0cmatch_length\x18\x04 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12h\n\x10required_classes\x18\x05 \x01(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.PasswordQualityPolicy.RequiredClasses\x12}\n\x1cmin_length_by_class_settings\x18\x06 \x01(\x0b\x32W.yandex.cloud.organizationmanager.v1.idp.PasswordQualityPolicy.MinLengthByClassSettings\x1aS\n\x0fRequiredClasses\x12\x0e\n\x06lowers\x18\x01 \x01(\x08\x12\x0e\n\x06uppers\x18\x02 \x01(\x08\x12\x0e\n\x06\x64igits\x18\x03 \x01(\x08\x12\x10\n\x08specials\x18\x04 \x01(\x08\x1a^\n\x18MinLengthByClassSettings\x12\x14\n\x03one\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x14\n\x03two\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x16\n\x05three\x18\x03 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\"Z\n\x16PasswordLifetimePolicy\x12\x1f\n\x0emin_days_count\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x1f\n\x0emax_days_count\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\"\x8b\x01\n\x1a\x42ruteforceProtectionPolicy\x12)\n\x06window\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12(\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x18\n\x08\x61ttempts\x18\x03 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0B~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.userpool_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_USERPOOL_LABELSENTRY']._loaded_options = None
  _globals['_USERPOOL_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['one']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['one']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['two']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['two']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['three']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS'].fields_by_name['three']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['max_length']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['max_length']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['min_length']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['min_length']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['match_length']._loaded_options = None
  _globals['_PASSWORDQUALITYPOLICY'].fields_by_name['match_length']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDLIFETIMEPOLICY'].fields_by_name['min_days_count']._loaded_options = None
  _globals['_PASSWORDLIFETIMEPOLICY'].fields_by_name['min_days_count']._serialized_options = b'\372\3071\003>=0'
  _globals['_PASSWORDLIFETIMEPOLICY'].fields_by_name['max_days_count']._loaded_options = None
  _globals['_PASSWORDLIFETIMEPOLICY'].fields_by_name['max_days_count']._serialized_options = b'\372\3071\003>=0'
  _globals['_BRUTEFORCEPROTECTIONPOLICY'].fields_by_name['attempts']._loaded_options = None
  _globals['_BRUTEFORCEPROTECTIONPOLICY'].fields_by_name['attempts']._serialized_options = b'\372\3071\002>0'
  _globals['_USERPOOL']._serialized_start=196
  _globals['_USERPOOL']._serialized_end=1046
  _globals['_USERPOOL_LABELSENTRY']._serialized_start=927
  _globals['_USERPOOL_LABELSENTRY']._serialized_end=972
  _globals['_USERPOOL_STATUS']._serialized_start=974
  _globals['_USERPOOL_STATUS']._serialized_end=1046
  _globals['_USERSETTINGS']._serialized_start=1049
  _globals['_USERSETTINGS']._serialized_end=1192
  _globals['_DOMAIN']._serialized_start=1195
  _globals['_DOMAIN']._serialized_end=1633
  _globals['_DOMAIN_STATUS']._serialized_start=1519
  _globals['_DOMAIN_STATUS']._serialized_end=1627
  _globals['_DOMAINCHALLENGE']._serialized_start=1636
  _globals['_DOMAINCHALLENGE']._serialized_end=2318
  _globals['_DOMAINCHALLENGE_DNSRECORD']._serialized_start=2003
  _globals['_DOMAINCHALLENGE_DNSRECORD']._serialized_end=2169
  _globals['_DOMAINCHALLENGE_DNSRECORD_TYPE']._serialized_start=2132
  _globals['_DOMAINCHALLENGE_DNSRECORD_TYPE']._serialized_end=2169
  _globals['_DOMAINCHALLENGE_TYPE']._serialized_start=2171
  _globals['_DOMAINCHALLENGE_TYPE']._serialized_end=2212
  _globals['_DOMAINCHALLENGE_STATUS']._serialized_start=2214
  _globals['_DOMAINCHALLENGE_STATUS']._serialized_end=2299
  _globals['_PASSWORDQUALITYPOLICY']._serialized_start=2321
  _globals['_PASSWORDQUALITYPOLICY']._serialized_end=2870
  _globals['_PASSWORDQUALITYPOLICY_REQUIREDCLASSES']._serialized_start=2691
  _globals['_PASSWORDQUALITYPOLICY_REQUIREDCLASSES']._serialized_end=2774
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS']._serialized_start=2776
  _globals['_PASSWORDQUALITYPOLICY_MINLENGTHBYCLASSSETTINGS']._serialized_end=2870
  _globals['_PASSWORDLIFETIMEPOLICY']._serialized_start=2872
  _globals['_PASSWORDLIFETIMEPOLICY']._serialized_end=2962
  _globals['_BRUTEFORCEPROTECTIONPOLICY']._serialized_start=2965
  _globals['_BRUTEFORCEPROTECTIONPOLICY']._serialized_end=3104
# @@protoc_insertion_point(module_scope)
