# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/userpool_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/userpool_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp import userpool_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_userpool__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/organizationmanager/v1/idp/userpool_service.proto\x12\'yandex.cloud.organizationmanager.v1.idp\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x36yandex/cloud/organizationmanager/v1/idp/userpool.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\"7\n\x12GetUserpoolRequest\x12!\n\x0buserpool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x98\x01\n\x14ListUserpoolsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"v\n\x15ListUserpoolsResponse\x12\x44\n\tuserpools\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.organizationmanager.v1.idp.Userpool\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x84\x06\n\x15\x43reateUserpoolRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x04name\x18\x02 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x04 \x03(\x0b\x32J.yandex.cloud.organizationmanager.v1.idp.CreateUserpoolRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\'\n\x11\x64\x65\x66\x61ult_subdomain\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12L\n\ruser_settings\x18\x06 \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.UserSettings\x12_\n\x17password_quality_policy\x18\x07 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.PasswordQualityPolicy\x12\x61\n\x18password_lifetime_policy\x18\x08 \x01(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.PasswordLifetimePolicy\x12i\n\x1c\x62ruteforce_protection_policy\x18\t \x01(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.idp.BruteforceProtectionPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16\x43reateUserpoolMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\"\x85\x06\n\x15UpdateUserpoolRequest\x12!\n\x0buserpool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x05 \x03(\x0b\x32J.yandex.cloud.organizationmanager.v1.idp.UpdateUserpoolRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12L\n\ruser_settings\x18\x06 \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.idp.UserSettings\x12_\n\x17password_quality_policy\x18\x07 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.idp.PasswordQualityPolicy\x12\x61\n\x18password_lifetime_policy\x18\x08 \x01(\x0b\x32?.yandex.cloud.organizationmanager.v1.idp.PasswordLifetimePolicy\x12i\n\x1c\x62ruteforce_protection_policy\x18\t \x01(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.idp.BruteforceProtectionPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateUserpoolMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\":\n\x15\x44\x65leteUserpoolRequest\x12!\n\x0buserpool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteUserpoolMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\"?\n\x18GetUserpoolDomainRequest\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"\x8c\x01\n\x1aListUserpoolDomainsRequest\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"x\n\x1bListUserpoolDomainsResponse\x12@\n\x07\x64omains\x18\x01 \x03(\x0b\x32/.yandex.cloud.organizationmanager.v1.idp.Domain\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"?\n\x18\x41\x64\x64UserpoolDomainRequest\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"@\n\x19\x41\x64\x64UserpoolDomainMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"D\n\x1dValidateUserpoolDomainRequest\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"E\n\x1eValidateUserpoolDomainMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"B\n\x1b\x44\x65leteUserpoolDomainRequest\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"C\n\x1c\x44\x65leteUserpoolDomainMetadata\x12\x13\n\x0buserpool_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"}\n\x1dListUserpoolOperationsRequest\x12\x1d\n\x0buserpool_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"p\n\x1eListUserpoolOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xeb\x18\n\x0fUserpoolService\x12\xb3\x01\n\x03Get\x12;.yandex.cloud.organizationmanager.v1.idp.GetUserpoolRequest\x1a\x31.yandex.cloud.organizationmanager.v1.idp.Userpool\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/organization-manager/v1/idp/userpools/{userpool_id}\x12\xb5\x01\n\x04List\x12=.yandex.cloud.organizationmanager.v1.idp.ListUserpoolsRequest\x1a>.yandex.cloud.organizationmanager.v1.idp.ListUserpoolsResponse\".\x82\xd3\xe4\x93\x02(\x12&/organization-manager/v1/idp/userpools\x12\xc4\x01\n\x06\x43reate\x12>.yandex.cloud.organizationmanager.v1.idp.CreateUserpoolRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*\"\n\x16\x43reateUserpoolMetadata\x12\x08Userpool\x82\xd3\xe4\x93\x02+\"&/organization-manager/v1/idp/userpools:\x01*\x12\xd2\x01\n\x06Update\x12>.yandex.cloud.organizationmanager.v1.idp.UpdateUserpoolRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*\"\n\x16UpdateUserpoolMetadata\x12\x08Userpool\x82\xd3\xe4\x93\x02\x39\x32\x34/organization-manager/v1/idp/userpools/{userpool_id}:\x01*\x12\xdc\x01\n\x06\x44\x65lete\x12>.yandex.cloud.organizationmanager.v1.idp.DeleteUserpoolRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*/\n\x16\x44\x65leteUserpoolMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36*4/organization-manager/v1/idp/userpools/{userpool_id}\x12\xce\x01\n\tGetDomain\x12\x41.yandex.cloud.organizationmanager.v1.idp.GetUserpoolDomainRequest\x1a/.yandex.cloud.organizationmanager.v1.idp.Domain\"M\x82\xd3\xe4\x93\x02G\x12\x45/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}\x12\xde\x01\n\x0bListDomains\x12\x43.yandex.cloud.organizationmanager.v1.idp.ListUserpoolDomainsRequest\x1a\x44.yandex.cloud.organizationmanager.v1.idp.ListUserpoolDomainsResponse\"D\x82\xd3\xe4\x93\x02>\x12</organization-manager/v1/idp/userpools/{userpool_id}/domains\x12\xe1\x01\n\tAddDomain\x12\x41.yandex.cloud.organizationmanager.v1.idp.AddUserpoolDomainRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*#\n\x19\x41\x64\x64UserpoolDomainMetadata\x12\x06\x44omain\x82\xd3\xe4\x93\x02\x41\"</organization-manager/v1/idp/userpools/{userpool_id}/domains:\x01*\x12\x83\x02\n\x0eValidateDomain\x12\x46.yandex.cloud.organizationmanager.v1.idp.ValidateUserpoolDomainRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*(\n\x1eValidateUserpoolDomainMetadata\x12\x06\x44omain\x82\xd3\xe4\x93\x02S\"N/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}:validate:\x01*\x12\x80\x02\n\x0c\x44\x65leteDomain\x12\x44.yandex.cloud.organizationmanager.v1.idp.DeleteUserpoolDomainRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*5\n\x1c\x44\x65leteUserpoolDomainMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02G*E/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}\x12\xea\x01\n\x0eListOperations\x12\x46.yandex.cloud.organizationmanager.v1.idp.ListUserpoolOperationsRequest\x1aG.yandex.cloud.organizationmanager.v1.idp.ListUserpoolOperationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/organization-manager/v1/idp/userpools/{userpool_id}/operations\x12\xc6\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"O\x82\xd3\xe4\x93\x02I\x12G/organization-manager/v1/idp/userpools/{resource_id}:listAccessBindings\x12\x85\x02\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x9d\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02K\"F/organization-manager/v1/idp/userpools/{resource_id}:setAccessBindings:\x01*\x12\x91\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\xa3\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02N2I/organization-manager/v1/idp/userpools/{resource_id}:updateAccessBindings:\x01*B~\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.userpool_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+yandex.cloud.api.organizationmanager.v1.idpZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp;idp'
  _globals['_GETUSERPOOLREQUEST'].fields_by_name['userpool_id']._loaded_options = None
  _globals['_GETUSERPOOLREQUEST'].fields_by_name['userpool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTUSERPOOLSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEUSERPOOLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['default_subdomain']._loaded_options = None
  _globals['_CREATEUSERPOOLREQUEST'].fields_by_name['default_subdomain']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_UPDATEUSERPOOLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEUSERPOOLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['userpool_id']._loaded_options = None
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['userpool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEUSERPOOLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEUSERPOOLREQUEST'].fields_by_name['userpool_id']._loaded_options = None
  _globals['_DELETEUSERPOOLREQUEST'].fields_by_name['userpool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTUSERPOOLDOMAINSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['userpool_id']._loaded_options = None
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['userpool_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERPOOLOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_USERPOOLSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0026\0224/organization-manager/v1/idp/userpools/{userpool_id}'
  _globals['_USERPOOLSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002(\022&/organization-manager/v1/idp/userpools'
  _globals['_USERPOOLSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateUserpoolMetadata\022\010Userpool\202\323\344\223\002+\"&/organization-manager/v1/idp/userpools:\001*'
  _globals['_USERPOOLSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateUserpoolMetadata\022\010Userpool\202\323\344\223\002924/organization-manager/v1/idp/userpools/{userpool_id}:\001*'
  _globals['_USERPOOLSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteUserpoolMetadata\022\025google.protobuf.Empty\202\323\344\223\0026*4/organization-manager/v1/idp/userpools/{userpool_id}'
  _globals['_USERPOOLSERVICE'].methods_by_name['GetDomain']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['GetDomain']._serialized_options = b'\202\323\344\223\002G\022E/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}'
  _globals['_USERPOOLSERVICE'].methods_by_name['ListDomains']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['ListDomains']._serialized_options = b'\202\323\344\223\002>\022</organization-manager/v1/idp/userpools/{userpool_id}/domains'
  _globals['_USERPOOLSERVICE'].methods_by_name['AddDomain']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['AddDomain']._serialized_options = b'\262\322*#\n\031AddUserpoolDomainMetadata\022\006Domain\202\323\344\223\002A\"</organization-manager/v1/idp/userpools/{userpool_id}/domains:\001*'
  _globals['_USERPOOLSERVICE'].methods_by_name['ValidateDomain']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['ValidateDomain']._serialized_options = b'\262\322*(\n\036ValidateUserpoolDomainMetadata\022\006Domain\202\323\344\223\002S\"N/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}:validate:\001*'
  _globals['_USERPOOLSERVICE'].methods_by_name['DeleteDomain']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['DeleteDomain']._serialized_options = b'\262\322*5\n\034DeleteUserpoolDomainMetadata\022\025google.protobuf.Empty\202\323\344\223\002G*E/organization-manager/v1/idp/userpools/{userpool_id}/domains/{domain}'
  _globals['_USERPOOLSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002A\022?/organization-manager/v1/idp/userpools/{userpool_id}/operations'
  _globals['_USERPOOLSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002I\022G/organization-manager/v1/idp/userpools/{resource_id}:listAccessBindings'
  _globals['_USERPOOLSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002K\"F/organization-manager/v1/idp/userpools/{resource_id}:setAccessBindings:\001*'
  _globals['_USERPOOLSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_USERPOOLSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002N2I/organization-manager/v1/idp/userpools/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETUSERPOOLREQUEST']._serialized_start=366
  _globals['_GETUSERPOOLREQUEST']._serialized_end=421
  _globals['_LISTUSERPOOLSREQUEST']._serialized_start=424
  _globals['_LISTUSERPOOLSREQUEST']._serialized_end=576
  _globals['_LISTUSERPOOLSRESPONSE']._serialized_start=578
  _globals['_LISTUSERPOOLSRESPONSE']._serialized_end=696
  _globals['_CREATEUSERPOOLREQUEST']._serialized_start=699
  _globals['_CREATEUSERPOOLREQUEST']._serialized_end=1471
  _globals['_CREATEUSERPOOLREQUEST_LABELSENTRY']._serialized_start=1426
  _globals['_CREATEUSERPOOLREQUEST_LABELSENTRY']._serialized_end=1471
  _globals['_CREATEUSERPOOLMETADATA']._serialized_start=1473
  _globals['_CREATEUSERPOOLMETADATA']._serialized_end=1518
  _globals['_UPDATEUSERPOOLREQUEST']._serialized_start=1521
  _globals['_UPDATEUSERPOOLREQUEST']._serialized_end=2294
  _globals['_UPDATEUSERPOOLREQUEST_LABELSENTRY']._serialized_start=1426
  _globals['_UPDATEUSERPOOLREQUEST_LABELSENTRY']._serialized_end=1471
  _globals['_UPDATEUSERPOOLMETADATA']._serialized_start=2296
  _globals['_UPDATEUSERPOOLMETADATA']._serialized_end=2341
  _globals['_DELETEUSERPOOLREQUEST']._serialized_start=2343
  _globals['_DELETEUSERPOOLREQUEST']._serialized_end=2401
  _globals['_DELETEUSERPOOLMETADATA']._serialized_start=2403
  _globals['_DELETEUSERPOOLMETADATA']._serialized_end=2448
  _globals['_GETUSERPOOLDOMAINREQUEST']._serialized_start=2450
  _globals['_GETUSERPOOLDOMAINREQUEST']._serialized_end=2513
  _globals['_LISTUSERPOOLDOMAINSREQUEST']._serialized_start=2516
  _globals['_LISTUSERPOOLDOMAINSREQUEST']._serialized_end=2656
  _globals['_LISTUSERPOOLDOMAINSRESPONSE']._serialized_start=2658
  _globals['_LISTUSERPOOLDOMAINSRESPONSE']._serialized_end=2778
  _globals['_ADDUSERPOOLDOMAINREQUEST']._serialized_start=2780
  _globals['_ADDUSERPOOLDOMAINREQUEST']._serialized_end=2843
  _globals['_ADDUSERPOOLDOMAINMETADATA']._serialized_start=2845
  _globals['_ADDUSERPOOLDOMAINMETADATA']._serialized_end=2909
  _globals['_VALIDATEUSERPOOLDOMAINREQUEST']._serialized_start=2911
  _globals['_VALIDATEUSERPOOLDOMAINREQUEST']._serialized_end=2979
  _globals['_VALIDATEUSERPOOLDOMAINMETADATA']._serialized_start=2981
  _globals['_VALIDATEUSERPOOLDOMAINMETADATA']._serialized_end=3050
  _globals['_DELETEUSERPOOLDOMAINREQUEST']._serialized_start=3052
  _globals['_DELETEUSERPOOLDOMAINREQUEST']._serialized_end=3118
  _globals['_DELETEUSERPOOLDOMAINMETADATA']._serialized_start=3120
  _globals['_DELETEUSERPOOLDOMAINMETADATA']._serialized_end=3187
  _globals['_LISTUSERPOOLOPERATIONSREQUEST']._serialized_start=3189
  _globals['_LISTUSERPOOLOPERATIONSREQUEST']._serialized_end=3314
  _globals['_LISTUSERPOOLOPERATIONSRESPONSE']._serialized_start=3316
  _globals['_LISTUSERPOOLOPERATIONSRESPONSE']._serialized_end=3428
  _globals['_USERPOOLSERVICE']._serialized_start=3431
  _globals['_USERPOOLSERVICE']._serialized_end=6610
# @@protoc_insertion_point(module_scope)
