# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/analysis/assistants.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/analysis/assistants.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/speechsense/v1/analysis/assistants.proto\x12$yandex.cloud.speechsense.v1.analysis\"^\n\nAssistants\x12P\n\x11\x61ssistant_results\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.speechsense.v1.analysis.AssistantResult\"t\n\x0f\x41ssistantResult\x12\x14\n\x0c\x61ssistant_id\x18\x01 \x01(\t\x12K\n\x07results\x18\x02 \x03(\x0b\x32:.yandex.cloud.speechsense.v1.analysis.AssistantFieldResult\"}\n\x14\x41ssistantFieldResult\x12\x10\n\x08\x66ield_id\x18\x01 \x01(\t\x12\x17\n\rstring_result\x18\x02 \x01(\tH\x00\x12\x14\n\nint_result\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x66loat_result\x18\x04 \x01(\x01H\x00\x42\x0c\n\nfield_typeB\x91\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x0f\x41ssistantsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.assistants_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\017AssistantsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_ASSISTANTS']._serialized_start=95
  _globals['_ASSISTANTS']._serialized_end=189
  _globals['_ASSISTANTRESULT']._serialized_start=191
  _globals['_ASSISTANTRESULT']._serialized_end=307
  _globals['_ASSISTANTFIELDRESULT']._serialized_start=309
  _globals['_ASSISTANTFIELDRESULT']._serialized_end=434
# @@protoc_insertion_point(module_scope)
