"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AgentRegistrationServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Register: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterRequest,
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterResponse,
    ]
    """Registers specified agent."""

    ExternalAgentRegister: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.ExternalAgentRegisterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Registers external agent."""

class AgentRegistrationServiceAsyncStub:
    Register: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterRequest,
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterResponse,
    ]
    """Registers specified agent."""

    ExternalAgentRegister: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.ExternalAgentRegisterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Registers external agent."""

class AgentRegistrationServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Register(
        self,
        request: yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterResponse, collections.abc.Awaitable[yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.RegisterResponse]]:
        """Registers specified agent."""

    @abc.abstractmethod
    def ExternalAgentRegister(
        self,
        request: yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2.ExternalAgentRegisterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Registers external agent."""

def add_AgentRegistrationServiceServicer_to_server(servicer: AgentRegistrationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
