# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/assistants_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/assistants_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.speechsense.v1 import assistant_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_assistant__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/speechsense/v1/assistants_service.proto\x12\x1byandex.cloud.speechsense.v1\x1a\x1cgoogle/api/annotations.proto\x1a+yandex/cloud/speechsense/v1/assistant.proto\"+\n\x15ListAssistantsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"T\n\x16ListAssistantsResponse\x12:\n\nassistants\x18\x01 \x03(\x0b\x32&.yandex.cloud.speechsense.v1.Assistant\"\x13\n\x11ListModelsRequest\"H\n\x12ListModelsResponse\x12\x32\n\x06models\x18\x01 \x03(\x0b\x32\".yandex.cloud.speechsense.v1.Model2\xd3\x02\n\x11\x41ssistantsService\x12\x9b\x01\n\x04List\x12\x32.yandex.cloud.speechsense.v1.ListAssistantsRequest\x1a\x33.yandex.cloud.speechsense.v1.ListAssistantsResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/speechsense/v1/assistants/list:\x01*\x12\x9f\x01\n\nListModels\x12..yandex.cloud.speechsense.v1.ListModelsRequest\x1a/.yandex.cloud.speechsense.v1.ListModelsResponse\"0\x82\xd3\xe4\x93\x02*\"%/speechsense/v1/assistants/listModels:\x01*B\x86\x01\n\x1fyandex.cloud.api.speechsense.v1B\x16\x41ssistantsServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.assistants_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\026AssistantsServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_ASSISTANTSSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ASSISTANTSSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002$\"\037/speechsense/v1/assistants/list:\001*'
  _globals['_ASSISTANTSSERVICE'].methods_by_name['ListModels']._loaded_options = None
  _globals['_ASSISTANTSSERVICE'].methods_by_name['ListModels']._serialized_options = b'\202\323\344\223\002*\"%/speechsense/v1/assistants/listModels:\001*'
  _globals['_LISTASSISTANTSREQUEST']._serialized_start=160
  _globals['_LISTASSISTANTSREQUEST']._serialized_end=203
  _globals['_LISTASSISTANTSRESPONSE']._serialized_start=205
  _globals['_LISTASSISTANTSRESPONSE']._serialized_end=289
  _globals['_LISTMODELSREQUEST']._serialized_start=291
  _globals['_LISTMODELSREQUEST']._serialized_end=310
  _globals['_LISTMODELSRESPONSE']._serialized_start=312
  _globals['_LISTMODELSRESPONSE']._serialized_end=384
  _globals['_ASSISTANTSSERVICE']._serialized_start=387
  _globals['_ASSISTANTSSERVICE']._serialized_end=726
# @@protoc_insertion_point(module_scope)
