# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/assistant.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/assistant.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/speechsense/v1/assistant.proto\x12\x1byandex.cloud.speechsense.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbb\x03\n\tAssistant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0e\n\x06prompt\x18\x06 \x01(\t\x12;\n\x06\x66ields\x18\x07 \x03(\x0b\x32+.yandex.cloud.speechsense.v1.AssistantField\x12\x0f\n\x07\x65nabled\x18\x08 \x01(\x08\x12\x42\n\x06labels\x18\t \x03(\x0b\x32\x32.yandex.cloud.speechsense.v1.Assistant.LabelsEntry\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12/\n\x0bmodified_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bmodified_by\x18\r \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x0e\x41ssistantField\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12=\n\x04type\x18\x04 \x01(\x0e\x32/.yandex.cloud.speechsense.v1.AssistantFieldType\"6\n\x05Model\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t*\x9e\x01\n\x12\x41ssistantFieldType\x12$\n ASSISTANT_FIELD_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x41SSISTANT_FIELD_TYPE_STRING\x10\x01\x12\x1f\n\x1b\x41SSISTANT_FIELD_TYPE_NUMBER\x10\x02\x12 \n\x1c\x41SSISTANT_FIELD_TYPE_DECIMAL\x10\x03\x42~\n\x1fyandex.cloud.api.speechsense.v1B\x0e\x41ssistantProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.assistant_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\016AssistantProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_ASSISTANT_LABELSENTRY']._loaded_options = None
  _globals['_ASSISTANT_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_ASSISTANTFIELDTYPE']._serialized_start=740
  _globals['_ASSISTANTFIELDTYPE']._serialized_end=898
  _globals['_ASSISTANT']._serialized_start=110
  _globals['_ASSISTANT']._serialized_end=553
  _globals['_ASSISTANT_LABELSENTRY']._serialized_start=508
  _globals['_ASSISTANT_LABELSENTRY']._serialized_end=553
  _globals['_ASSISTANTFIELD']._serialized_start=555
  _globals['_ASSISTANTFIELD']._serialized_end=681
  _globals['_MODEL']._serialized_start=683
  _globals['_MODEL']._serialized_end=737
# @@protoc_insertion_point(module_scope)
