# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp import user_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__pb2
from yandex.cloud.organizationmanager.v1.idp import user_service_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/organizationmanager/v1/idp/user_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class UserServiceStub(object):
    """A set of methods for managing users in the Identity Provider system.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Get',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GetUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__pb2.User.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/List',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Create',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Update',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.UpdateUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Delete',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.DeleteUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.SetOwnPassword = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/SetOwnPassword',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOwnPasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.SetOthersPassword = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/SetOthersPassword',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOthersPasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Suspend = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Suspend',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SuspendUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Reactivate = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Reactivate',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ReactivateUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.GeneratePassword = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/GeneratePassword',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordResponse.FromString,
                _registered_method=True)
        self.GetSelfPasswordMetadata = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/GetSelfPasswordMetadata',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.PasswordMetadata.FromString,
                _registered_method=True)
        self.ConvertToExternal = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/ConvertToExternal',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ConvertToExternalUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.SetPasswordHash = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/SetPasswordHash',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetPasswordHashRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ResolveExternalIds = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/ResolveExternalIds',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsResponse.FromString,
                _registered_method=True)


class UserServiceServicer(object):
    """A set of methods for managing users in the Identity Provider system.
    """

    def Get(self, request, context):
        """Returns the specified user.

        To get the list of available users, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of users in the specified userpool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a user in the specified userpool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetOwnPassword(self, request, context):
        """Sets the password for the authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetOthersPassword(self, request, context):
        """Sets the password for another user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Suspend(self, request, context):
        """Suspends the specified user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reactivate(self, request, context):
        """Reactivates a previously suspended user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GeneratePassword(self, request, context):
        """Generates a new password.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSelfPasswordMetadata(self, request, context):
        """Returns metadata about the authenticated user's password.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConvertToExternal(self, request, context):
        """Converts a user to use external authentication.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPasswordHash(self, request, context):
        """Sets a password hash for the specified user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResolveExternalIds(self, request, context):
        """Resolves external IDs to internal user IDs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GetUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__pb2.User.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.CreateUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.UpdateUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.DeleteUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SetOwnPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.SetOwnPassword,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOwnPasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SetOthersPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.SetOthersPassword,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOthersPasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Suspend': grpc.unary_unary_rpc_method_handler(
                    servicer.Suspend,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SuspendUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Reactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.Reactivate,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ReactivateUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GeneratePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.GeneratePassword,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordResponse.SerializeToString,
            ),
            'GetSelfPasswordMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSelfPasswordMetadata,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.PasswordMetadata.SerializeToString,
            ),
            'ConvertToExternal': grpc.unary_unary_rpc_method_handler(
                    servicer.ConvertToExternal,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ConvertToExternalUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SetPasswordHash': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPasswordHash,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetPasswordHashRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ResolveExternalIds': grpc.unary_unary_rpc_method_handler(
                    servicer.ResolveExternalIds,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.organizationmanager.v1.idp.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.organizationmanager.v1.idp.UserService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UserService(object):
    """A set of methods for managing users in the Identity Provider system.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Get',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GetUserRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__pb2.User.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/List',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Create',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.CreateUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Update',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.UpdateUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Delete',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.DeleteUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetOwnPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/SetOwnPassword',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOwnPasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetOthersPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/SetOthersPassword',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOthersPasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Suspend(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Suspend',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SuspendUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Reactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Reactivate',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ReactivateUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GeneratePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/GeneratePassword',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSelfPasswordMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/GetSelfPasswordMetadata',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.PasswordMetadata.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ConvertToExternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/ConvertToExternal',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ConvertToExternalUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetPasswordHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/SetPasswordHash',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetPasswordHashRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ResolveExternalIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/ResolveExternalIds',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
