# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/application.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/application.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/compute/v1/application.proto\x12\x17yandex.cloud.compute.v1\x1a\x1dyandex/cloud/validation.proto\"\\\n\x06Secret\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x03key\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=256\x12\x1c\n\nversion_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x99\x03\n\x15\x43ontainerSolutionSpec\x12 \n\nproduct_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x62\n\x07secrets\x18\x02 \x03(\x0b\x32;.yandex.cloud.compute.v1.ContainerSolutionSpec.SecretsEntryB\x14\x82\xc8\x31\x05<=100\xb2\xc8\x31\x07\x1a\x05<=100\x12u\n\x0b\x65nvironment\x18\x03 \x03(\x0b\x32?.yandex.cloud.compute.v1.ContainerSolutionSpec.EnvironmentEntryB\x1f\x82\xc8\x31\x05<=100\x8a\xc8\x31\x07<=10000\xb2\xc8\x31\x07\x1a\x05<=100\x1aO\n\x0cSecretsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.yandex.cloud.compute.v1.Secret:\x02\x38\x01\x1a\x32\n\x10\x45nvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x01\n\nBackupSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12,\n\x12initial_policy_ids\x18\x02 \x03(\tB\x10\x82\xc8\x31\x04<=50\x8a\xc8\x31\x04\x31-50\x12\x1c\n\x14recovery_from_backup\x18\x03 \x01(\x08\x12\x1c\n\tbackup_id\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12+\n\x18instance_registration_id\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\xa2\x01\n\x0b\x41pplication\x12L\n\x12\x63ontainer_solution\x18\x01 \x01(\x0b\x32..yandex.cloud.compute.v1.ContainerSolutionSpecH\x00\x12\x38\n\x0b\x63loudbackup\x18\x02 \x01(\x0b\x32#.yandex.cloud.compute.v1.BackupSpecB\x0b\n\tcontainerBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.application_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_SECRET'].fields_by_name['id']._loaded_options = None
  _globals['_SECRET'].fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SECRET'].fields_by_name['key']._loaded_options = None
  _globals['_SECRET'].fields_by_name['key']._serialized_options = b'\350\3071\001\212\3101\005<=256'
  _globals['_SECRET'].fields_by_name['version_id']._loaded_options = None
  _globals['_SECRET'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CONTAINERSOLUTIONSPEC_SECRETSENTRY']._loaded_options = None
  _globals['_CONTAINERSOLUTIONSPEC_SECRETSENTRY']._serialized_options = b'8\001'
  _globals['_CONTAINERSOLUTIONSPEC_ENVIRONMENTENTRY']._loaded_options = None
  _globals['_CONTAINERSOLUTIONSPEC_ENVIRONMENTENTRY']._serialized_options = b'8\001'
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['product_id']._loaded_options = None
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['product_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['secrets']._loaded_options = None
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['secrets']._serialized_options = b'\202\3101\005<=100\262\3101\007\032\005<=100'
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['environment']._loaded_options = None
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['environment']._serialized_options = b'\202\3101\005<=100\212\3101\007<=10000\262\3101\007\032\005<=100'
  _globals['_BACKUPSPEC'].fields_by_name['initial_policy_ids']._loaded_options = None
  _globals['_BACKUPSPEC'].fields_by_name['initial_policy_ids']._serialized_options = b'\202\3101\004<=50\212\3101\0041-50'
  _globals['_BACKUPSPEC'].fields_by_name['backup_id']._loaded_options = None
  _globals['_BACKUPSPEC'].fields_by_name['backup_id']._serialized_options = b'\212\3101\005<=100'
  _globals['_BACKUPSPEC'].fields_by_name['instance_registration_id']._loaded_options = None
  _globals['_BACKUPSPEC'].fields_by_name['instance_registration_id']._serialized_options = b'\212\3101\005<=100'
  _globals['_SECRET']._serialized_start=101
  _globals['_SECRET']._serialized_end=193
  _globals['_CONTAINERSOLUTIONSPEC']._serialized_start=196
  _globals['_CONTAINERSOLUTIONSPEC']._serialized_end=605
  _globals['_CONTAINERSOLUTIONSPEC_SECRETSENTRY']._serialized_start=474
  _globals['_CONTAINERSOLUTIONSPEC_SECRETSENTRY']._serialized_end=553
  _globals['_CONTAINERSOLUTIONSPEC_ENVIRONMENTENTRY']._serialized_start=555
  _globals['_CONTAINERSOLUTIONSPEC_ENVIRONMENTENTRY']._serialized_end=605
  _globals['_BACKUPSPEC']._serialized_start=608
  _globals['_BACKUPSPEC']._serialized_end=788
  _globals['_APPLICATION']._serialized_start=791
  _globals['_APPLICATION']._serialized_end=953
# @@protoc_insertion_point(module_scope)
