"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.address_pb2
import yandex.cloud.vpc.v1.address_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AddressServiceStub:
    """A set of methods for managing Address resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.GetAddressRequest,
        yandex.cloud.vpc.v1.address_pb2.Address,
    ]
    """Returns the specified Address resource.

    To get the list of all available Address resources, make a [List] request.
    """

    GetByValue: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.GetAddressByValueRequest,
        yandex.cloud.vpc.v1.address_pb2.Address,
    ]
    """Returns the specified Address resource by a given value.

    To get the list of all available Address resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressesRequest,
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressesResponse,
    ]
    """Retrieves the list of Address resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.CreateAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an address in the specified folder and network."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.UpdateAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified address."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.DeleteAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified address."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsRequest,
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsResponse,
    ]
    """List operations for the specified address."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.MoveAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move an address to another folder"""

class AddressServiceAsyncStub:
    """A set of methods for managing Address resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.GetAddressRequest,
        yandex.cloud.vpc.v1.address_pb2.Address,
    ]
    """Returns the specified Address resource.

    To get the list of all available Address resources, make a [List] request.
    """

    GetByValue: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.GetAddressByValueRequest,
        yandex.cloud.vpc.v1.address_pb2.Address,
    ]
    """Returns the specified Address resource by a given value.

    To get the list of all available Address resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressesRequest,
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressesResponse,
    ]
    """Retrieves the list of Address resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.CreateAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an address in the specified folder and network."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.UpdateAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified address."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.DeleteAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified address."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsRequest,
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsResponse,
    ]
    """List operations for the specified address."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.MoveAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move an address to another folder"""

class AddressServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Address resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.GetAddressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.address_pb2.Address, collections.abc.Awaitable[yandex.cloud.vpc.v1.address_pb2.Address]]:
        """Returns the specified Address resource.

        To get the list of all available Address resources, make a [List] request.
        """

    @abc.abstractmethod
    def GetByValue(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.GetAddressByValueRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.address_pb2.Address, collections.abc.Awaitable[yandex.cloud.vpc.v1.address_pb2.Address]]:
        """Returns the specified Address resource by a given value.

        To get the list of all available Address resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.ListAddressesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.address_service_pb2.ListAddressesResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.address_service_pb2.ListAddressesResponse]]:
        """Retrieves the list of Address resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.CreateAddressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an address in the specified folder and network."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.UpdateAddressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified address."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.DeleteAddressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified address."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsResponse]]:
        """List operations for the specified address."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.MoveAddressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Move an address to another folder"""

def add_AddressServiceServicer_to_server(servicer: AddressServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
